Change Log
==========

Unreleased
----------

**Changed**

- Added model class :class:`s2.models.S2Paper`
- Added model class :class:`s2.models.S2Author`
- Added api function :func:`s2.api.get_paper`
- Added api function :func:`s2.api.get_author`
- Added documentation
